<?php

namespace GeorgRinger\News\Tests\Unit\ViewHelpers;

use GeorgRinger\News\ViewHelpers\SimplePrevNextViewHelper;
use TYPO3\TestingFramework\Core\BaseTestCase;

/**
 * This file is part of the "news" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 */

/**
 * Test for SimplePrevNextViewHelper
 */
class SimplePrevNextViewHelperTest extends BaseTestCase
{

    /** @var \PHPUnit_Framework_MockObject_MockObject|\TYPO3\TestingFramework\Core\AccessibleObjectInterface */
    protected $viewHelper;

    public function setup(): void
    {
        $this->viewHelper = $this->getAccessibleMock(SimplePrevNextViewHelper::class, ['getRawRecord']);
    }

    /**
     * @test
     */
    public function wrongIdWillReturnNullForObject()
    {
        $this->viewHelper->expects($this->any())->method('getRawRecord')->withAnyParameters()->will($this->returnValue(null));

        $out = $this->viewHelper->_call('getObject', 0);
        $this->assertEquals($out, null);
    }

    /**
     * @test
     */
    public function queryResultWillReturnCorrectOutputForAllLinks()
    {
        $viewHelper = $this->getAccessibleMock(SimplePrevNextViewHelper::class, ['getObject']);

        $in = [
            'prev' => ['uid' => 123],
            'next' => ['uid' => 789],
        ];
        $exp = ['prev' => 123, 'next' => 789];
        $viewHelper->expects($this->at(0))->method('getObject')->will($this->returnValue(123));
        $viewHelper->expects($this->at(1))->method('getObject')->will($this->returnValue(789));
        $out = $viewHelper->_call('mapResultToObjects', $in);
        $this->assertEquals($out, $exp);
    }

    /**
     * @test
     */
    public function queryResultWillReturnCorrectOutputFor2Links()
    {
        $viewHelper = $this->getAccessibleMock(SimplePrevNextViewHelper::class, ['getObject']);

        $in = [
            'prev' => ['uid' => 147],
        ];
        $exp = ['prev' => 147];
        $viewHelper->expects($this->at(0))->method('getObject')->will($this->returnValue(147));
        $out = $viewHelper->_call('mapResultToObjects', $in);
        $this->assertEquals($out, $exp);
    }

    /**
     * @test
     */
    public function queryResultWillReturnCorrectOutputFor1Link()
    {
        $viewHelper = $this->getAccessibleMock(SimplePrevNextViewHelper::class, ['getObject']);

        $in = [
            'next' => ['uid' => 369],
        ];
        $exp = ['next' => 369];
        $viewHelper->expects($this->at(0))->method('getObject')->will($this->returnValue(369));
        $out = $viewHelper->_call('mapResultToObjects', $in);
        $this->assertEquals($out, $exp);
    }
}
